#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FengdieSitesOwner(object):

    def __init__(self):
        self._nick = None
        self._origin_user_id = None

    @property
    def nick(self):
        return self._nick

    @nick.setter
    def nick(self, value):
        self._nick = value
    @property
    def origin_user_id(self):
        return self._origin_user_id

    @origin_user_id.setter
    def origin_user_id(self, value):
        self._origin_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.nick:
            if hasattr(self.nick, 'to_alipay_dict'):
                params['nick'] = self.nick.to_alipay_dict()
            else:
                params['nick'] = self.nick
        if self.origin_user_id:
            if hasattr(self.origin_user_id, 'to_alipay_dict'):
                params['origin_user_id'] = self.origin_user_id.to_alipay_dict()
            else:
                params['origin_user_id'] = self.origin_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FengdieSitesOwner()
        if 'nick' in d:
            o.nick = d['nick']
        if 'origin_user_id' in d:
            o.origin_user_id = d['origin_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PointPrizeInfo(object):

    def __init__(self):
        self._end_time = None
        self._exchange_point = None
        self._intro = None
        self._pic_url = None
        self._prize_name = None
        self._prize_no = None
        self._prize_type = None
        self._start_time = None
        self._stock = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def exchange_point(self):
        return self._exchange_point

    @exchange_point.setter
    def exchange_point(self, value):
        self._exchange_point = value
    @property
    def intro(self):
        return self._intro

    @intro.setter
    def intro(self, value):
        self._intro = value
    @property
    def pic_url(self):
        return self._pic_url

    @pic_url.setter
    def pic_url(self, value):
        self._pic_url = value
    @property
    def prize_name(self):
        return self._prize_name

    @prize_name.setter
    def prize_name(self, value):
        self._prize_name = value
    @property
    def prize_no(self):
        return self._prize_no

    @prize_no.setter
    def prize_no(self, value):
        self._prize_no = value
    @property
    def prize_type(self):
        return self._prize_type

    @prize_type.setter
    def prize_type(self, value):
        self._prize_type = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def stock(self):
        return self._stock

    @stock.setter
    def stock(self, value):
        self._stock = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.exchange_point:
            if hasattr(self.exchange_point, 'to_alipay_dict'):
                params['exchange_point'] = self.exchange_point.to_alipay_dict()
            else:
                params['exchange_point'] = self.exchange_point
        if self.intro:
            if hasattr(self.intro, 'to_alipay_dict'):
                params['intro'] = self.intro.to_alipay_dict()
            else:
                params['intro'] = self.intro
        if self.pic_url:
            if hasattr(self.pic_url, 'to_alipay_dict'):
                params['pic_url'] = self.pic_url.to_alipay_dict()
            else:
                params['pic_url'] = self.pic_url
        if self.prize_name:
            if hasattr(self.prize_name, 'to_alipay_dict'):
                params['prize_name'] = self.prize_name.to_alipay_dict()
            else:
                params['prize_name'] = self.prize_name
        if self.prize_no:
            if hasattr(self.prize_no, 'to_alipay_dict'):
                params['prize_no'] = self.prize_no.to_alipay_dict()
            else:
                params['prize_no'] = self.prize_no
        if self.prize_type:
            if hasattr(self.prize_type, 'to_alipay_dict'):
                params['prize_type'] = self.prize_type.to_alipay_dict()
            else:
                params['prize_type'] = self.prize_type
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.stock:
            if hasattr(self.stock, 'to_alipay_dict'):
                params['stock'] = self.stock.to_alipay_dict()
            else:
                params['stock'] = self.stock
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PointPrizeInfo()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'exchange_point' in d:
            o.exchange_point = d['exchange_point']
        if 'intro' in d:
            o.intro = d['intro']
        if 'pic_url' in d:
            o.pic_url = d['pic_url']
        if 'prize_name' in d:
            o.prize_name = d['prize_name']
        if 'prize_no' in d:
            o.prize_no = d['prize_no']
        if 'prize_type' in d:
            o.prize_type = d['prize_type']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'stock' in d:
            o.stock = d['stock']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPayCodecAcodeDecodeUseModel(object):

    def __init__(self):
        self._acode_scene = None
        self._biz_scene = None
        self._device_id = None
        self._dynamic_id = None
        self._institution_type = None
        self._lbs_info = None
        self._scan_time = None
        self._scene_no = None

    @property
    def acode_scene(self):
        return self._acode_scene

    @acode_scene.setter
    def acode_scene(self, value):
        self._acode_scene = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def dynamic_id(self):
        return self._dynamic_id

    @dynamic_id.setter
    def dynamic_id(self, value):
        self._dynamic_id = value
    @property
    def institution_type(self):
        return self._institution_type

    @institution_type.setter
    def institution_type(self, value):
        self._institution_type = value
    @property
    def lbs_info(self):
        return self._lbs_info

    @lbs_info.setter
    def lbs_info(self, value):
        self._lbs_info = value
    @property
    def scan_time(self):
        return self._scan_time

    @scan_time.setter
    def scan_time(self, value):
        self._scan_time = value
    @property
    def scene_no(self):
        return self._scene_no

    @scene_no.setter
    def scene_no(self, value):
        self._scene_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.acode_scene:
            if hasattr(self.acode_scene, 'to_alipay_dict'):
                params['acode_scene'] = self.acode_scene.to_alipay_dict()
            else:
                params['acode_scene'] = self.acode_scene
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.dynamic_id:
            if hasattr(self.dynamic_id, 'to_alipay_dict'):
                params['dynamic_id'] = self.dynamic_id.to_alipay_dict()
            else:
                params['dynamic_id'] = self.dynamic_id
        if self.institution_type:
            if hasattr(self.institution_type, 'to_alipay_dict'):
                params['institution_type'] = self.institution_type.to_alipay_dict()
            else:
                params['institution_type'] = self.institution_type
        if self.lbs_info:
            if hasattr(self.lbs_info, 'to_alipay_dict'):
                params['lbs_info'] = self.lbs_info.to_alipay_dict()
            else:
                params['lbs_info'] = self.lbs_info
        if self.scan_time:
            if hasattr(self.scan_time, 'to_alipay_dict'):
                params['scan_time'] = self.scan_time.to_alipay_dict()
            else:
                params['scan_time'] = self.scan_time
        if self.scene_no:
            if hasattr(self.scene_no, 'to_alipay_dict'):
                params['scene_no'] = self.scene_no.to_alipay_dict()
            else:
                params['scene_no'] = self.scene_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPayCodecAcodeDecodeUseModel()
        if 'acode_scene' in d:
            o.acode_scene = d['acode_scene']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'dynamic_id' in d:
            o.dynamic_id = d['dynamic_id']
        if 'institution_type' in d:
            o.institution_type = d['institution_type']
        if 'lbs_info' in d:
            o.lbs_info = d['lbs_info']
        if 'scan_time' in d:
            o.scan_time = d['scan_time']
        if 'scene_no' in d:
            o.scene_no = d['scene_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SkuInfo import SkuInfo


class AlipayUserAliyunbenefitSyncModel(object):

    def __init__(self):
        self._category_code = None
        self._item_id = None
        self._item_title = None
        self._main_pic = None
        self._op_action = None
        self._op_timestamp = None
        self._operator = None
        self._reserve_price = None
        self._shop_name = None
        self._sku_infos = None

    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_title(self):
        return self._item_title

    @item_title.setter
    def item_title(self, value):
        self._item_title = value
    @property
    def main_pic(self):
        return self._main_pic

    @main_pic.setter
    def main_pic(self, value):
        self._main_pic = value
    @property
    def op_action(self):
        return self._op_action

    @op_action.setter
    def op_action(self, value):
        self._op_action = value
    @property
    def op_timestamp(self):
        return self._op_timestamp

    @op_timestamp.setter
    def op_timestamp(self, value):
        self._op_timestamp = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def reserve_price(self):
        return self._reserve_price

    @reserve_price.setter
    def reserve_price(self, value):
        self._reserve_price = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def sku_infos(self):
        return self._sku_infos

    @sku_infos.setter
    def sku_infos(self, value):
        if isinstance(value, list):
            self._sku_infos = list()
            for i in value:
                if isinstance(i, SkuInfo):
                    self._sku_infos.append(i)
                else:
                    self._sku_infos.append(SkuInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_title:
            if hasattr(self.item_title, 'to_alipay_dict'):
                params['item_title'] = self.item_title.to_alipay_dict()
            else:
                params['item_title'] = self.item_title
        if self.main_pic:
            if hasattr(self.main_pic, 'to_alipay_dict'):
                params['main_pic'] = self.main_pic.to_alipay_dict()
            else:
                params['main_pic'] = self.main_pic
        if self.op_action:
            if hasattr(self.op_action, 'to_alipay_dict'):
                params['op_action'] = self.op_action.to_alipay_dict()
            else:
                params['op_action'] = self.op_action
        if self.op_timestamp:
            if hasattr(self.op_timestamp, 'to_alipay_dict'):
                params['op_timestamp'] = self.op_timestamp.to_alipay_dict()
            else:
                params['op_timestamp'] = self.op_timestamp
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.reserve_price:
            if hasattr(self.reserve_price, 'to_alipay_dict'):
                params['reserve_price'] = self.reserve_price.to_alipay_dict()
            else:
                params['reserve_price'] = self.reserve_price
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.sku_infos:
            if isinstance(self.sku_infos, list):
                for i in range(0, len(self.sku_infos)):
                    element = self.sku_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sku_infos[i] = element.to_alipay_dict()
            if hasattr(self.sku_infos, 'to_alipay_dict'):
                params['sku_infos'] = self.sku_infos.to_alipay_dict()
            else:
                params['sku_infos'] = self.sku_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAliyunbenefitSyncModel()
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_title' in d:
            o.item_title = d['item_title']
        if 'main_pic' in d:
            o.main_pic = d['main_pic']
        if 'op_action' in d:
            o.op_action = d['op_action']
        if 'op_timestamp' in d:
            o.op_timestamp = d['op_timestamp']
        if 'operator' in d:
            o.operator = d['operator']
        if 'reserve_price' in d:
            o.reserve_price = d['reserve_price']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'sku_infos' in d:
            o.sku_infos = d['sku_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceCityfacilitatorStationQueryModel(object):

    def __init__(self):
        self._city_code = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceCityfacilitatorStationQueryModel()
        if 'city_code' in d:
            o.city_code = d['city_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppFlowStatusQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppFlowStatusQueryResponse, self).__init__()
        self._ext_msg = None
        self._merchant_order_id = None
        self._status = None
        self._trade_id = None

    @property
    def ext_msg(self):
        return self._ext_msg

    @ext_msg.setter
    def ext_msg(self, value):
        self._ext_msg = value
    @property
    def merchant_order_id(self):
        return self._merchant_order_id

    @merchant_order_id.setter
    def merchant_order_id(self, value):
        self._merchant_order_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def trade_id(self):
        return self._trade_id

    @trade_id.setter
    def trade_id(self, value):
        self._trade_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppFlowStatusQueryResponse, self).parse_response_content(response_content)
        if 'ext_msg' in response:
            self.ext_msg = response['ext_msg']
        if 'merchant_order_id' in response:
            self.merchant_order_id = response['merchant_order_id']
        if 'status' in response:
            self.status = response['status']
        if 'trade_id' in response:
            self.trade_id = response['trade_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdXwbtestabcAbcQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdXwbtestabcAbcQueryResponse, self).__init__()
        self._xwb = None

    @property
    def xwb(self):
        return self._xwb

    @xwb.setter
    def xwb(self, value):
        self._xwb = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdXwbtestabcAbcQueryResponse, self).parse_response_content(response_content)
        if 'xwb' in response:
            self.xwb = response['xwb']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UserMailInfoOrder(object):

    def __init__(self):
        self._city = None
        self._country = None
        self._county_district = None
        self._detail_address = None
        self._ip_role_id = None
        self._name = None
        self._province = None
        self._street = None
        self._telephone = None

    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def country(self):
        return self._country

    @country.setter
    def country(self, value):
        self._country = value
    @property
    def county_district(self):
        return self._county_district

    @county_district.setter
    def county_district(self, value):
        self._county_district = value
    @property
    def detail_address(self):
        return self._detail_address

    @detail_address.setter
    def detail_address(self, value):
        self._detail_address = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def street(self):
        return self._street

    @street.setter
    def street(self, value):
        self._street = value
    @property
    def telephone(self):
        return self._telephone

    @telephone.setter
    def telephone(self, value):
        self._telephone = value


    def to_alipay_dict(self):
        params = dict()
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.country:
            if hasattr(self.country, 'to_alipay_dict'):
                params['country'] = self.country.to_alipay_dict()
            else:
                params['country'] = self.country
        if self.county_district:
            if hasattr(self.county_district, 'to_alipay_dict'):
                params['county_district'] = self.county_district.to_alipay_dict()
            else:
                params['county_district'] = self.county_district
        if self.detail_address:
            if hasattr(self.detail_address, 'to_alipay_dict'):
                params['detail_address'] = self.detail_address.to_alipay_dict()
            else:
                params['detail_address'] = self.detail_address
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.street:
            if hasattr(self.street, 'to_alipay_dict'):
                params['street'] = self.street.to_alipay_dict()
            else:
                params['street'] = self.street
        if self.telephone:
            if hasattr(self.telephone, 'to_alipay_dict'):
                params['telephone'] = self.telephone.to_alipay_dict()
            else:
                params['telephone'] = self.telephone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserMailInfoOrder()
        if 'city' in d:
            o.city = d['city']
        if 'country' in d:
            o.country = d['country']
        if 'county_district' in d:
            o.county_district = d['county_district']
        if 'detail_address' in d:
            o.detail_address = d['detail_address']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'name' in d:
            o.name = d['name']
        if 'province' in d:
            o.province = d['province']
        if 'street' in d:
            o.street = d['street']
        if 'telephone' in d:
            o.telephone = d['telephone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundTransBatchCreateorderResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransBatchCreateorderResponse, self).__init__()
        self._biz_type = None
        self._ext_param = None
        self._transfer_no = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def transfer_no(self):
        return self._transfer_no

    @transfer_no.setter
    def transfer_no(self, value):
        self._transfer_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransBatchCreateorderResponse, self).parse_response_content(response_content)
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'ext_param' in response:
            self.ext_param = response['ext_param']
        if 'transfer_no' in response:
            self.transfer_no = response['transfer_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppCommunityRoomDeleteModel(object):

    def __init__(self):
        self._community_short_name = None
        self._out_room_id = None
        self._room_id = None

    @property
    def community_short_name(self):
        return self._community_short_name

    @community_short_name.setter
    def community_short_name(self, value):
        self._community_short_name = value
    @property
    def out_room_id(self):
        return self._out_room_id

    @out_room_id.setter
    def out_room_id(self, value):
        self._out_room_id = value
    @property
    def room_id(self):
        return self._room_id

    @room_id.setter
    def room_id(self, value):
        self._room_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.community_short_name:
            if hasattr(self.community_short_name, 'to_alipay_dict'):
                params['community_short_name'] = self.community_short_name.to_alipay_dict()
            else:
                params['community_short_name'] = self.community_short_name
        if self.out_room_id:
            if hasattr(self.out_room_id, 'to_alipay_dict'):
                params['out_room_id'] = self.out_room_id.to_alipay_dict()
            else:
                params['out_room_id'] = self.out_room_id
        if self.room_id:
            if hasattr(self.room_id, 'to_alipay_dict'):
                params['room_id'] = self.room_id.to_alipay_dict()
            else:
                params['room_id'] = self.room_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppCommunityRoomDeleteModel()
        if 'community_short_name' in d:
            o.community_short_name = d['community_short_name']
        if 'out_room_id' in d:
            o.out_room_id = d['out_room_id']
        if 'room_id' in d:
            o.room_id = d['room_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayWeiboEbppRechargeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayWeiboEbppRechargeResponse, self).__init__()
        self._partnerpuccharge = None

    @property
    def partnerpuccharge(self):
        return self._partnerpuccharge

    @partnerpuccharge.setter
    def partnerpuccharge(self, value):
        self._partnerpuccharge = value

    def parse_response_content(self, response_content):
        response = super(AlipayWeiboEbppRechargeResponse, self).parse_response_content(response_content)
        if 'partnerpuccharge' in response:
            self.partnerpuccharge = response['partnerpuccharge']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ContractInfo import ContractInfo


class AlipayBossContractManagementCreateModel(object):

    def __init__(self):
        self._biz_source = None
        self._contract_batch_no = None
        self._contract_info_list = None
        self._process_instance_id = None
        self._task_id = None

    @property
    def biz_source(self):
        return self._biz_source

    @biz_source.setter
    def biz_source(self, value):
        self._biz_source = value
    @property
    def contract_batch_no(self):
        return self._contract_batch_no

    @contract_batch_no.setter
    def contract_batch_no(self, value):
        self._contract_batch_no = value
    @property
    def contract_info_list(self):
        return self._contract_info_list

    @contract_info_list.setter
    def contract_info_list(self, value):
        if isinstance(value, list):
            self._contract_info_list = list()
            for i in value:
                if isinstance(i, ContractInfo):
                    self._contract_info_list.append(i)
                else:
                    self._contract_info_list.append(ContractInfo.from_alipay_dict(i))
    @property
    def process_instance_id(self):
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, value):
        self._process_instance_id = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_source:
            if hasattr(self.biz_source, 'to_alipay_dict'):
                params['biz_source'] = self.biz_source.to_alipay_dict()
            else:
                params['biz_source'] = self.biz_source
        if self.contract_batch_no:
            if hasattr(self.contract_batch_no, 'to_alipay_dict'):
                params['contract_batch_no'] = self.contract_batch_no.to_alipay_dict()
            else:
                params['contract_batch_no'] = self.contract_batch_no
        if self.contract_info_list:
            if isinstance(self.contract_info_list, list):
                for i in range(0, len(self.contract_info_list)):
                    element = self.contract_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.contract_info_list[i] = element.to_alipay_dict()
            if hasattr(self.contract_info_list, 'to_alipay_dict'):
                params['contract_info_list'] = self.contract_info_list.to_alipay_dict()
            else:
                params['contract_info_list'] = self.contract_info_list
        if self.process_instance_id:
            if hasattr(self.process_instance_id, 'to_alipay_dict'):
                params['process_instance_id'] = self.process_instance_id.to_alipay_dict()
            else:
                params['process_instance_id'] = self.process_instance_id
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossContractManagementCreateModel()
        if 'biz_source' in d:
            o.biz_source = d['biz_source']
        if 'contract_batch_no' in d:
            o.contract_batch_no = d['contract_batch_no']
        if 'contract_info_list' in d:
            o.contract_info_list = d['contract_info_list']
        if 'process_instance_id' in d:
            o.process_instance_id = d['process_instance_id']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankPaymentTradeNormalpayOrderCreateModel(object):

    def __init__(self):
        self._amount = None
        self._biz_channel = None
        self._biz_no = None
        self._buyer_info = None
        self._card_no = None
        self._close_time = None
        self._currency_value = None
        self._ext_info = None
        self._ipid = None
        self._iproleid = None
        self._order_type = None
        self._payee_fund_detail = None
        self._payer_fund_detail = None
        self._remark = None
        self._request_no = None
        self._request_time = None
        self._seller_info = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_channel(self):
        return self._biz_channel

    @biz_channel.setter
    def biz_channel(self, value):
        self._biz_channel = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def buyer_info(self):
        return self._buyer_info

    @buyer_info.setter
    def buyer_info(self, value):
        self._buyer_info = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def close_time(self):
        return self._close_time

    @close_time.setter
    def close_time(self, value):
        self._close_time = value
    @property
    def currency_value(self):
        return self._currency_value

    @currency_value.setter
    def currency_value(self, value):
        self._currency_value = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def ipid(self):
        return self._ipid

    @ipid.setter
    def ipid(self, value):
        self._ipid = value
    @property
    def iproleid(self):
        return self._iproleid

    @iproleid.setter
    def iproleid(self, value):
        self._iproleid = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def payee_fund_detail(self):
        return self._payee_fund_detail

    @payee_fund_detail.setter
    def payee_fund_detail(self, value):
        self._payee_fund_detail = value
    @property
    def payer_fund_detail(self):
        return self._payer_fund_detail

    @payer_fund_detail.setter
    def payer_fund_detail(self, value):
        self._payer_fund_detail = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value
    @property
    def request_time(self):
        return self._request_time

    @request_time.setter
    def request_time(self, value):
        self._request_time = value
    @property
    def seller_info(self):
        return self._seller_info

    @seller_info.setter
    def seller_info(self, value):
        self._seller_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.biz_channel:
            if hasattr(self.biz_channel, 'to_alipay_dict'):
                params['biz_channel'] = self.biz_channel.to_alipay_dict()
            else:
                params['biz_channel'] = self.biz_channel
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.buyer_info:
            if hasattr(self.buyer_info, 'to_alipay_dict'):
                params['buyer_info'] = self.buyer_info.to_alipay_dict()
            else:
                params['buyer_info'] = self.buyer_info
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.close_time:
            if hasattr(self.close_time, 'to_alipay_dict'):
                params['close_time'] = self.close_time.to_alipay_dict()
            else:
                params['close_time'] = self.close_time
        if self.currency_value:
            if hasattr(self.currency_value, 'to_alipay_dict'):
                params['currency_value'] = self.currency_value.to_alipay_dict()
            else:
                params['currency_value'] = self.currency_value
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.ipid:
            if hasattr(self.ipid, 'to_alipay_dict'):
                params['ipid'] = self.ipid.to_alipay_dict()
            else:
                params['ipid'] = self.ipid
        if self.iproleid:
            if hasattr(self.iproleid, 'to_alipay_dict'):
                params['iproleid'] = self.iproleid.to_alipay_dict()
            else:
                params['iproleid'] = self.iproleid
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.payee_fund_detail:
            if hasattr(self.payee_fund_detail, 'to_alipay_dict'):
                params['payee_fund_detail'] = self.payee_fund_detail.to_alipay_dict()
            else:
                params['payee_fund_detail'] = self.payee_fund_detail
        if self.payer_fund_detail:
            if hasattr(self.payer_fund_detail, 'to_alipay_dict'):
                params['payer_fund_detail'] = self.payer_fund_detail.to_alipay_dict()
            else:
                params['payer_fund_detail'] = self.payer_fund_detail
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.request_no:
            if hasattr(self.request_no, 'to_alipay_dict'):
                params['request_no'] = self.request_no.to_alipay_dict()
            else:
                params['request_no'] = self.request_no
        if self.request_time:
            if hasattr(self.request_time, 'to_alipay_dict'):
                params['request_time'] = self.request_time.to_alipay_dict()
            else:
                params['request_time'] = self.request_time
        if self.seller_info:
            if hasattr(self.seller_info, 'to_alipay_dict'):
                params['seller_info'] = self.seller_info.to_alipay_dict()
            else:
                params['seller_info'] = self.seller_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankPaymentTradeNormalpayOrderCreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'biz_channel' in d:
            o.biz_channel = d['biz_channel']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'buyer_info' in d:
            o.buyer_info = d['buyer_info']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'close_time' in d:
            o.close_time = d['close_time']
        if 'currency_value' in d:
            o.currency_value = d['currency_value']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'ipid' in d:
            o.ipid = d['ipid']
        if 'iproleid' in d:
            o.iproleid = d['iproleid']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'payee_fund_detail' in d:
            o.payee_fund_detail = d['payee_fund_detail']
        if 'payer_fund_detail' in d:
            o.payer_fund_detail = d['payer_fund_detail']
        if 'remark' in d:
            o.remark = d['remark']
        if 'request_no' in d:
            o.request_no = d['request_no']
        if 'request_time' in d:
            o.request_time = d['request_time']
        if 'seller_info' in d:
            o.seller_info = d['seller_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnswerSelectDTO(object):

    def __init__(self):
        self._label = None
        self._value = None

    @property
    def label(self):
        return self._label

    @label.setter
    def label(self, value):
        self._label = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.label:
            if hasattr(self.label, 'to_alipay_dict'):
                params['label'] = self.label.to_alipay_dict()
            else:
                params['label'] = self.label
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnswerSelectDTO()
        if 'label' in d:
            o.label = d['label']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MorphoAppItem import MorphoAppItem
from alipay.aop.api.domain.MorphoPaginator import MorphoPaginator


class AlipayOpenMiniMorphoApplistBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniMorphoApplistBatchqueryResponse, self).__init__()
        self._data_list = None
        self._paginator = None

    @property
    def data_list(self):
        return self._data_list

    @data_list.setter
    def data_list(self, value):
        if isinstance(value, list):
            self._data_list = list()
            for i in value:
                if isinstance(i, MorphoAppItem):
                    self._data_list.append(i)
                else:
                    self._data_list.append(MorphoAppItem.from_alipay_dict(i))
    @property
    def paginator(self):
        return self._paginator

    @paginator.setter
    def paginator(self, value):
        if isinstance(value, MorphoPaginator):
            self._paginator = value
        else:
            self._paginator = MorphoPaginator.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniMorphoApplistBatchqueryResponse, self).parse_response_content(response_content)
        if 'data_list' in response:
            self.data_list = response['data_list']
        if 'paginator' in response:
            self.paginator = response['paginator']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingRefundorderSyncModel(object):

    def __init__(self):
        self._car_number = None
        self._order_no = None
        self._out_refund_no = None
        self._refund_money = None
        self._refund_time = None
        self._user_id = None

    @property
    def car_number(self):
        return self._car_number

    @car_number.setter
    def car_number(self, value):
        self._car_number = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_refund_no(self):
        return self._out_refund_no

    @out_refund_no.setter
    def out_refund_no(self, value):
        self._out_refund_no = value
    @property
    def refund_money(self):
        return self._refund_money

    @refund_money.setter
    def refund_money(self, value):
        self._refund_money = value
    @property
    def refund_time(self):
        return self._refund_time

    @refund_time.setter
    def refund_time(self, value):
        self._refund_time = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.car_number:
            if hasattr(self.car_number, 'to_alipay_dict'):
                params['car_number'] = self.car_number.to_alipay_dict()
            else:
                params['car_number'] = self.car_number
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.out_refund_no:
            if hasattr(self.out_refund_no, 'to_alipay_dict'):
                params['out_refund_no'] = self.out_refund_no.to_alipay_dict()
            else:
                params['out_refund_no'] = self.out_refund_no
        if self.refund_money:
            if hasattr(self.refund_money, 'to_alipay_dict'):
                params['refund_money'] = self.refund_money.to_alipay_dict()
            else:
                params['refund_money'] = self.refund_money
        if self.refund_time:
            if hasattr(self.refund_time, 'to_alipay_dict'):
                params['refund_time'] = self.refund_time.to_alipay_dict()
            else:
                params['refund_time'] = self.refund_time
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingRefundorderSyncModel()
        if 'car_number' in d:
            o.car_number = d['car_number']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'out_refund_no' in d:
            o.out_refund_no = d['out_refund_no']
        if 'refund_money' in d:
            o.refund_money = d['refund_money']
        if 'refund_time' in d:
            o.refund_time = d['refund_time']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AdUser import AdUser


class AlipayCommerceTransportAdUserCreateModel(object):

    def __init__(self):
        self._ad_user = None

    @property
    def ad_user(self):
        return self._ad_user

    @ad_user.setter
    def ad_user(self, value):
        if isinstance(value, AdUser):
            self._ad_user = value
        else:
            self._ad_user = AdUser.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.ad_user:
            if hasattr(self.ad_user, 'to_alipay_dict'):
                params['ad_user'] = self.ad_user.to_alipay_dict()
            else:
                params['ad_user'] = self.ad_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportAdUserCreateModel()
        if 'ad_user' in d:
            o.ad_user = d['ad_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingCampaignAppleActivityConsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignAppleActivityConsultResponse, self).__init__()
        self._activity_status = None
        self._bind_status = None
        self._result_code = None
        self._result_desc = None
        self._success = None

    @property
    def activity_status(self):
        return self._activity_status

    @activity_status.setter
    def activity_status(self, value):
        self._activity_status = value
    @property
    def bind_status(self):
        return self._bind_status

    @bind_status.setter
    def bind_status(self, value):
        self._bind_status = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_desc(self):
        return self._result_desc

    @result_desc.setter
    def result_desc(self, value):
        self._result_desc = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignAppleActivityConsultResponse, self).parse_response_content(response_content)
        if 'activity_status' in response:
            self.activity_status = response['activity_status']
        if 'bind_status' in response:
            self.bind_status = response['bind_status']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_desc' in response:
            self.result_desc = response['result_desc']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AmountWf import AmountWf


class RepayRecordVO(object):

    def __init__(self):
        self._accountextno = None
        self._repayamt = None
        self._repaydate = None
        self._repaytype = None

    @property
    def accountextno(self):
        return self._accountextno

    @accountextno.setter
    def accountextno(self, value):
        self._accountextno = value
    @property
    def repayamt(self):
        return self._repayamt

    @repayamt.setter
    def repayamt(self, value):
        if isinstance(value, AmountWf):
            self._repayamt = value
        else:
            self._repayamt = AmountWf.from_alipay_dict(value)
    @property
    def repaydate(self):
        return self._repaydate

    @repaydate.setter
    def repaydate(self, value):
        self._repaydate = value
    @property
    def repaytype(self):
        return self._repaytype

    @repaytype.setter
    def repaytype(self, value):
        self._repaytype = value


    def to_alipay_dict(self):
        params = dict()
        if self.accountextno:
            if hasattr(self.accountextno, 'to_alipay_dict'):
                params['accountextno'] = self.accountextno.to_alipay_dict()
            else:
                params['accountextno'] = self.accountextno
        if self.repayamt:
            if hasattr(self.repayamt, 'to_alipay_dict'):
                params['repayamt'] = self.repayamt.to_alipay_dict()
            else:
                params['repayamt'] = self.repayamt
        if self.repaydate:
            if hasattr(self.repaydate, 'to_alipay_dict'):
                params['repaydate'] = self.repaydate.to_alipay_dict()
            else:
                params['repaydate'] = self.repaydate
        if self.repaytype:
            if hasattr(self.repaytype, 'to_alipay_dict'):
                params['repaytype'] = self.repaytype.to_alipay_dict()
            else:
                params['repaytype'] = self.repaytype
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RepayRecordVO()
        if 'accountextno' in d:
            o.accountextno = d['accountextno']
        if 'repayamt' in d:
            o.repayamt = d['repayamt']
        if 'repaydate' in d:
            o.repaydate = d['repaydate']
        if 'repaytype' in d:
            o.repaytype = d['repaytype']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CreditBankCredit import CreditBankCredit


class AlipayCommerceEducateCreditbankCreditQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateCreditbankCreditQueryResponse, self).__init__()
        self._credit = None

    @property
    def credit(self):
        return self._credit

    @credit.setter
    def credit(self, value):
        if isinstance(value, list):
            self._credit = list()
            for i in value:
                if isinstance(i, CreditBankCredit):
                    self._credit.append(i)
                else:
                    self._credit.append(CreditBankCredit.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateCreditbankCreditQueryResponse, self).parse_response_content(response_content)
        if 'credit' in response:
            self.credit = response['credit']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayQueryCardModelResult import AlipayQueryCardModelResult


class AlipayCommerceTransportOfflinepayVirtualcardBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportOfflinepayVirtualcardBatchqueryResponse, self).__init__()
        self._card_models = None
        self._error_message = None
        self._sub_error_code = None

    @property
    def card_models(self):
        return self._card_models

    @card_models.setter
    def card_models(self, value):
        if isinstance(value, list):
            self._card_models = list()
            for i in value:
                if isinstance(i, AlipayQueryCardModelResult):
                    self._card_models.append(i)
                else:
                    self._card_models.append(AlipayQueryCardModelResult.from_alipay_dict(i))
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def sub_error_code(self):
        return self._sub_error_code

    @sub_error_code.setter
    def sub_error_code(self, value):
        self._sub_error_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportOfflinepayVirtualcardBatchqueryResponse, self).parse_response_content(response_content)
        if 'card_models' in response:
            self.card_models = response['card_models']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'sub_error_code' in response:
            self.sub_error_code = response['sub_error_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SiData(object):

    def __init__(self):
        self._request_id = None
        self._service_return_url = None
        self._target_extend_params = None
        self._target_idcard = None
        self._target_idcard_type = None
        self._target_mobile = None
        self._target_sicard_no = None
        self._target_user_id = None
        self._target_user_name = None
        self._template_data = None
        self._template_id = None
        self._template_version = None

    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def service_return_url(self):
        return self._service_return_url

    @service_return_url.setter
    def service_return_url(self, value):
        self._service_return_url = value
    @property
    def target_extend_params(self):
        return self._target_extend_params

    @target_extend_params.setter
    def target_extend_params(self, value):
        self._target_extend_params = value
    @property
    def target_idcard(self):
        return self._target_idcard

    @target_idcard.setter
    def target_idcard(self, value):
        self._target_idcard = value
    @property
    def target_idcard_type(self):
        return self._target_idcard_type

    @target_idcard_type.setter
    def target_idcard_type(self, value):
        self._target_idcard_type = value
    @property
    def target_mobile(self):
        return self._target_mobile

    @target_mobile.setter
    def target_mobile(self, value):
        self._target_mobile = value
    @property
    def target_sicard_no(self):
        return self._target_sicard_no

    @target_sicard_no.setter
    def target_sicard_no(self, value):
        self._target_sicard_no = value
    @property
    def target_user_id(self):
        return self._target_user_id

    @target_user_id.setter
    def target_user_id(self, value):
        self._target_user_id = value
    @property
    def target_user_name(self):
        return self._target_user_name

    @target_user_name.setter
    def target_user_name(self, value):
        self._target_user_name = value
    @property
    def template_data(self):
        return self._template_data

    @template_data.setter
    def template_data(self, value):
        self._template_data = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def template_version(self):
        return self._template_version

    @template_version.setter
    def template_version(self, value):
        self._template_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.service_return_url:
            if hasattr(self.service_return_url, 'to_alipay_dict'):
                params['service_return_url'] = self.service_return_url.to_alipay_dict()
            else:
                params['service_return_url'] = self.service_return_url
        if self.target_extend_params:
            if hasattr(self.target_extend_params, 'to_alipay_dict'):
                params['target_extend_params'] = self.target_extend_params.to_alipay_dict()
            else:
                params['target_extend_params'] = self.target_extend_params
        if self.target_idcard:
            if hasattr(self.target_idcard, 'to_alipay_dict'):
                params['target_idcard'] = self.target_idcard.to_alipay_dict()
            else:
                params['target_idcard'] = self.target_idcard
        if self.target_idcard_type:
            if hasattr(self.target_idcard_type, 'to_alipay_dict'):
                params['target_idcard_type'] = self.target_idcard_type.to_alipay_dict()
            else:
                params['target_idcard_type'] = self.target_idcard_type
        if self.target_mobile:
            if hasattr(self.target_mobile, 'to_alipay_dict'):
                params['target_mobile'] = self.target_mobile.to_alipay_dict()
            else:
                params['target_mobile'] = self.target_mobile
        if self.target_sicard_no:
            if hasattr(self.target_sicard_no, 'to_alipay_dict'):
                params['target_sicard_no'] = self.target_sicard_no.to_alipay_dict()
            else:
                params['target_sicard_no'] = self.target_sicard_no
        if self.target_user_id:
            if hasattr(self.target_user_id, 'to_alipay_dict'):
                params['target_user_id'] = self.target_user_id.to_alipay_dict()
            else:
                params['target_user_id'] = self.target_user_id
        if self.target_user_name:
            if hasattr(self.target_user_name, 'to_alipay_dict'):
                params['target_user_name'] = self.target_user_name.to_alipay_dict()
            else:
                params['target_user_name'] = self.target_user_name
        if self.template_data:
            if hasattr(self.template_data, 'to_alipay_dict'):
                params['template_data'] = self.template_data.to_alipay_dict()
            else:
                params['template_data'] = self.template_data
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.template_version:
            if hasattr(self.template_version, 'to_alipay_dict'):
                params['template_version'] = self.template_version.to_alipay_dict()
            else:
                params['template_version'] = self.template_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SiData()
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'service_return_url' in d:
            o.service_return_url = d['service_return_url']
        if 'target_extend_params' in d:
            o.target_extend_params = d['target_extend_params']
        if 'target_idcard' in d:
            o.target_idcard = d['target_idcard']
        if 'target_idcard_type' in d:
            o.target_idcard_type = d['target_idcard_type']
        if 'target_mobile' in d:
            o.target_mobile = d['target_mobile']
        if 'target_sicard_no' in d:
            o.target_sicard_no = d['target_sicard_no']
        if 'target_user_id' in d:
            o.target_user_id = d['target_user_id']
        if 'target_user_name' in d:
            o.target_user_name = d['target_user_name']
        if 'template_data' in d:
            o.template_data = d['template_data']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'template_version' in d:
            o.template_version = d['template_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.StepcounterDataInfo import StepcounterDataInfo


class AlipayUserStepcounterDataBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserStepcounterDataBatchqueryResponse, self).__init__()
        self._step_info = None

    @property
    def step_info(self):
        return self._step_info

    @step_info.setter
    def step_info(self, value):
        if isinstance(value, list):
            self._step_info = list()
            for i in value:
                if isinstance(i, StepcounterDataInfo):
                    self._step_info.append(i)
                else:
                    self._step_info.append(StepcounterDataInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayUserStepcounterDataBatchqueryResponse, self).parse_response_content(response_content)
        if 'step_info' in response:
            self.step_info = response['step_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZolozIdentificationCustomerEnrollcertifyQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZolozIdentificationCustomerEnrollcertifyQueryResponse, self).__init__()
        self._attack = None
        self._biz_id = None
        self._img_str = None

    @property
    def attack(self):
        return self._attack

    @attack.setter
    def attack(self, value):
        self._attack = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def img_str(self):
        return self._img_str

    @img_str.setter
    def img_str(self, value):
        self._img_str = value

    def parse_response_content(self, response_content):
        response = super(ZolozIdentificationCustomerEnrollcertifyQueryResponse, self).parse_response_content(response_content)
        if 'attack' in response:
            self.attack = response['attack']
        if 'biz_id' in response:
            self.biz_id = response['biz_id']
        if 'img_str' in response:
            self.img_str = response['img_str']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeQueryModel(object):

    def __init__(self):
        self._org_pid = None
        self._out_trade_no = None
        self._query_options = None
        self._trade_no = None

    @property
    def org_pid(self):
        return self._org_pid

    @org_pid.setter
    def org_pid(self, value):
        self._org_pid = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def query_options(self):
        return self._query_options

    @query_options.setter
    def query_options(self, value):
        if isinstance(value, list):
            self._query_options = list()
            for i in value:
                self._query_options.append(i)
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.org_pid:
            if hasattr(self.org_pid, 'to_alipay_dict'):
                params['org_pid'] = self.org_pid.to_alipay_dict()
            else:
                params['org_pid'] = self.org_pid
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.query_options:
            if isinstance(self.query_options, list):
                for i in range(0, len(self.query_options)):
                    element = self.query_options[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.query_options[i] = element.to_alipay_dict()
            if hasattr(self.query_options, 'to_alipay_dict'):
                params['query_options'] = self.query_options.to_alipay_dict()
            else:
                params['query_options'] = self.query_options
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeQueryModel()
        if 'org_pid' in d:
            o.org_pid = d['org_pid']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'query_options' in d:
            o.query_options = d['query_options']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InvoiceContactInfo(object):

    def __init__(self):
        self._contact_addr = None
        self._contact_mail = None
        self._contact_mobile = None
        self._contact_name = None

    @property
    def contact_addr(self):
        return self._contact_addr

    @contact_addr.setter
    def contact_addr(self, value):
        self._contact_addr = value
    @property
    def contact_mail(self):
        return self._contact_mail

    @contact_mail.setter
    def contact_mail(self, value):
        self._contact_mail = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.contact_addr:
            if hasattr(self.contact_addr, 'to_alipay_dict'):
                params['contact_addr'] = self.contact_addr.to_alipay_dict()
            else:
                params['contact_addr'] = self.contact_addr
        if self.contact_mail:
            if hasattr(self.contact_mail, 'to_alipay_dict'):
                params['contact_mail'] = self.contact_mail.to_alipay_dict()
            else:
                params['contact_mail'] = self.contact_mail
        if self.contact_mobile:
            if hasattr(self.contact_mobile, 'to_alipay_dict'):
                params['contact_mobile'] = self.contact_mobile.to_alipay_dict()
            else:
                params['contact_mobile'] = self.contact_mobile
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceContactInfo()
        if 'contact_addr' in d:
            o.contact_addr = d['contact_addr']
        if 'contact_mail' in d:
            o.contact_mail = d['contact_mail']
        if 'contact_mobile' in d:
            o.contact_mobile = d['contact_mobile']
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ScheduleInfo import ScheduleInfo


class CalendarScheduleInfo(object):

    def __init__(self):
        self._duration = None
        self._schedule = None
        self._unit = None

    @property
    def duration(self):
        return self._duration

    @duration.setter
    def duration(self, value):
        self._duration = value
    @property
    def schedule(self):
        return self._schedule

    @schedule.setter
    def schedule(self, value):
        if isinstance(value, list):
            self._schedule = list()
            for i in value:
                if isinstance(i, ScheduleInfo):
                    self._schedule.append(i)
                else:
                    self._schedule.append(ScheduleInfo.from_alipay_dict(i))
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.duration:
            if hasattr(self.duration, 'to_alipay_dict'):
                params['duration'] = self.duration.to_alipay_dict()
            else:
                params['duration'] = self.duration
        if self.schedule:
            if isinstance(self.schedule, list):
                for i in range(0, len(self.schedule)):
                    element = self.schedule[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.schedule[i] = element.to_alipay_dict()
            if hasattr(self.schedule, 'to_alipay_dict'):
                params['schedule'] = self.schedule.to_alipay_dict()
            else:
                params['schedule'] = self.schedule
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CalendarScheduleInfo()
        if 'duration' in d:
            o.duration = d['duration']
        if 'schedule' in d:
            o.schedule = d['schedule']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayItemGoodsList import AlipayItemGoodsList


class AlipayDataDataexchangeSfasdfResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataexchangeSfasdfResponse, self).__init__()
        self._azxfghd = None
        self._gfdhsdasafg = None
        self._gfhjfdsa = None
        self._ghjfdsafgh = None
        self._sdvsdv = None
        self._wrty = None

    @property
    def azxfghd(self):
        return self._azxfghd

    @azxfghd.setter
    def azxfghd(self, value):
        if isinstance(value, list):
            self._azxfghd = list()
            for i in value:
                self._azxfghd.append(i)
    @property
    def gfdhsdasafg(self):
        return self._gfdhsdasafg

    @gfdhsdasafg.setter
    def gfdhsdasafg(self, value):
        if isinstance(value, list):
            self._gfdhsdasafg = list()
            for i in value:
                self._gfdhsdasafg.append(i)
    @property
    def gfhjfdsa(self):
        return self._gfhjfdsa

    @gfhjfdsa.setter
    def gfhjfdsa(self, value):
        if isinstance(value, list):
            self._gfhjfdsa = list()
            for i in value:
                self._gfhjfdsa.append(i)
    @property
    def ghjfdsafgh(self):
        return self._ghjfdsafgh

    @ghjfdsafgh.setter
    def ghjfdsafgh(self, value):
        if isinstance(value, list):
            self._ghjfdsafgh = list()
            for i in value:
                self._ghjfdsafgh.append(i)
    @property
    def sdvsdv(self):
        return self._sdvsdv

    @sdvsdv.setter
    def sdvsdv(self, value):
        self._sdvsdv = value
    @property
    def wrty(self):
        return self._wrty

    @wrty.setter
    def wrty(self, value):
        if isinstance(value, list):
            self._wrty = list()
            for i in value:
                if isinstance(i, AlipayItemGoodsList):
                    self._wrty.append(i)
                else:
                    self._wrty.append(AlipayItemGoodsList.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataexchangeSfasdfResponse, self).parse_response_content(response_content)
        if 'azxfghd' in response:
            self.azxfghd = response['azxfghd']
        if 'gfdhsdasafg' in response:
            self.gfdhsdasafg = response['gfdhsdasafg']
        if 'gfhjfdsa' in response:
            self.gfhjfdsa = response['gfhjfdsa']
        if 'ghjfdsafgh' in response:
            self.ghjfdsafgh = response['ghjfdsafgh']
        if 'sdvsdv' in response:
            self.sdvsdv = response['sdvsdv']
        if 'wrty' in response:
            self.wrty = response['wrty']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ShopRec import ShopRec
from alipay.aop.api.domain.VoucherRec import VoucherRec


class AlipayDataDataserviceShoppingmallrecShopandvoucherQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceShoppingmallrecShopandvoucherQueryResponse, self).__init__()
        self._recommend_id = None
        self._request_id = None
        self._shop_recommend_list = None
        self._voucher_recommend_list = None

    @property
    def recommend_id(self):
        return self._recommend_id

    @recommend_id.setter
    def recommend_id(self, value):
        self._recommend_id = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_recommend_list(self):
        return self._shop_recommend_list

    @shop_recommend_list.setter
    def shop_recommend_list(self, value):
        if isinstance(value, list):
            self._shop_recommend_list = list()
            for i in value:
                if isinstance(i, ShopRec):
                    self._shop_recommend_list.append(i)
                else:
                    self._shop_recommend_list.append(ShopRec.from_alipay_dict(i))
    @property
    def voucher_recommend_list(self):
        return self._voucher_recommend_list

    @voucher_recommend_list.setter
    def voucher_recommend_list(self, value):
        if isinstance(value, list):
            self._voucher_recommend_list = list()
            for i in value:
                if isinstance(i, VoucherRec):
                    self._voucher_recommend_list.append(i)
                else:
                    self._voucher_recommend_list.append(VoucherRec.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceShoppingmallrecShopandvoucherQueryResponse, self).parse_response_content(response_content)
        if 'recommend_id' in response:
            self.recommend_id = response['recommend_id']
        if 'request_id' in response:
            self.request_id = response['request_id']
        if 'shop_recommend_list' in response:
            self.shop_recommend_list = response['shop_recommend_list']
        if 'voucher_recommend_list' in response:
            self.voucher_recommend_list = response['voucher_recommend_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.Result import Result


class AlipayOverseasTravelBenefitChangeNotifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTravelBenefitChangeNotifyResponse, self).__init__()
        self._acquirer_id = None
        self._psp_id = None
        self._result = None

    @property
    def acquirer_id(self):
        return self._acquirer_id

    @acquirer_id.setter
    def acquirer_id(self, value):
        self._acquirer_id = value
    @property
    def psp_id(self):
        return self._psp_id

    @psp_id.setter
    def psp_id(self, value):
        self._psp_id = value
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        if isinstance(value, Result):
            self._result = value
        else:
            self._result = Result.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTravelBenefitChangeNotifyResponse, self).parse_response_content(response_content)
        if 'acquirer_id' in response:
            self.acquirer_id = response['acquirer_id']
        if 'psp_id' in response:
            self.psp_id = response['psp_id']
        if 'result' in response:
            self.result = response['result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateFacefeatureGroupkeyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateFacefeatureGroupkeyQueryResponse, self).__init__()
        self._group_key = None

    @property
    def group_key(self):
        return self._group_key

    @group_key.setter
    def group_key(self, value):
        self._group_key = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateFacefeatureGroupkeyQueryResponse, self).parse_response_content(response_content)
        if 'group_key' in response:
            self.group_key = response['group_key']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GoodsDetailInfo import GoodsDetailInfo
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.UserIdentityExt import UserIdentityExt
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.UserIdentityExt import UserIdentityExt


class AlipayBusinessPaymenthubPayModel(object):

    def __init__(self):
        self._channel = None
        self._goods_infos = None
        self._is_async_pay = None
        self._merchant_order_no = None
        self._order_amount = None
        self._pay_amount = None
        self._pay_mode = None
        self._pay_request_no = None
        self._pay_terminal = None
        self._payee = None
        self._payee_ext = None
        self._payer = None
        self._payer_ext = None
        self._remark = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def goods_infos(self):
        return self._goods_infos

    @goods_infos.setter
    def goods_infos(self, value):
        if isinstance(value, list):
            self._goods_infos = list()
            for i in value:
                if isinstance(i, GoodsDetailInfo):
                    self._goods_infos.append(i)
                else:
                    self._goods_infos.append(GoodsDetailInfo.from_alipay_dict(i))
    @property
    def is_async_pay(self):
        return self._is_async_pay

    @is_async_pay.setter
    def is_async_pay(self, value):
        self._is_async_pay = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pay_mode(self):
        return self._pay_mode

    @pay_mode.setter
    def pay_mode(self, value):
        self._pay_mode = value
    @property
    def pay_request_no(self):
        return self._pay_request_no

    @pay_request_no.setter
    def pay_request_no(self, value):
        self._pay_request_no = value
    @property
    def pay_terminal(self):
        return self._pay_terminal

    @pay_terminal.setter
    def pay_terminal(self, value):
        self._pay_terminal = value
    @property
    def payee(self):
        return self._payee

    @payee.setter
    def payee(self, value):
        if isinstance(value, UserIdentity):
            self._payee = value
        else:
            self._payee = UserIdentity.from_alipay_dict(value)
    @property
    def payee_ext(self):
        return self._payee_ext

    @payee_ext.setter
    def payee_ext(self, value):
        if isinstance(value, UserIdentityExt):
            self._payee_ext = value
        else:
            self._payee_ext = UserIdentityExt.from_alipay_dict(value)
    @property
    def payer(self):
        return self._payer

    @payer.setter
    def payer(self, value):
        if isinstance(value, UserIdentity):
            self._payer = value
        else:
            self._payer = UserIdentity.from_alipay_dict(value)
    @property
    def payer_ext(self):
        return self._payer_ext

    @payer_ext.setter
    def payer_ext(self, value):
        if isinstance(value, UserIdentityExt):
            self._payer_ext = value
        else:
            self._payer_ext = UserIdentityExt.from_alipay_dict(value)
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.goods_infos:
            if isinstance(self.goods_infos, list):
                for i in range(0, len(self.goods_infos)):
                    element = self.goods_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_infos[i] = element.to_alipay_dict()
            if hasattr(self.goods_infos, 'to_alipay_dict'):
                params['goods_infos'] = self.goods_infos.to_alipay_dict()
            else:
                params['goods_infos'] = self.goods_infos
        if self.is_async_pay:
            if hasattr(self.is_async_pay, 'to_alipay_dict'):
                params['is_async_pay'] = self.is_async_pay.to_alipay_dict()
            else:
                params['is_async_pay'] = self.is_async_pay
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.pay_mode:
            if hasattr(self.pay_mode, 'to_alipay_dict'):
                params['pay_mode'] = self.pay_mode.to_alipay_dict()
            else:
                params['pay_mode'] = self.pay_mode
        if self.pay_request_no:
            if hasattr(self.pay_request_no, 'to_alipay_dict'):
                params['pay_request_no'] = self.pay_request_no.to_alipay_dict()
            else:
                params['pay_request_no'] = self.pay_request_no
        if self.pay_terminal:
            if hasattr(self.pay_terminal, 'to_alipay_dict'):
                params['pay_terminal'] = self.pay_terminal.to_alipay_dict()
            else:
                params['pay_terminal'] = self.pay_terminal
        if self.payee:
            if hasattr(self.payee, 'to_alipay_dict'):
                params['payee'] = self.payee.to_alipay_dict()
            else:
                params['payee'] = self.payee
        if self.payee_ext:
            if hasattr(self.payee_ext, 'to_alipay_dict'):
                params['payee_ext'] = self.payee_ext.to_alipay_dict()
            else:
                params['payee_ext'] = self.payee_ext
        if self.payer:
            if hasattr(self.payer, 'to_alipay_dict'):
                params['payer'] = self.payer.to_alipay_dict()
            else:
                params['payer'] = self.payer
        if self.payer_ext:
            if hasattr(self.payer_ext, 'to_alipay_dict'):
                params['payer_ext'] = self.payer_ext.to_alipay_dict()
            else:
                params['payer_ext'] = self.payer_ext
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBusinessPaymenthubPayModel()
        if 'channel' in d:
            o.channel = d['channel']
        if 'goods_infos' in d:
            o.goods_infos = d['goods_infos']
        if 'is_async_pay' in d:
            o.is_async_pay = d['is_async_pay']
        if 'merchant_order_no' in d:
            o.merchant_order_no = d['merchant_order_no']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'pay_mode' in d:
            o.pay_mode = d['pay_mode']
        if 'pay_request_no' in d:
            o.pay_request_no = d['pay_request_no']
        if 'pay_terminal' in d:
            o.pay_terminal = d['pay_terminal']
        if 'payee' in d:
            o.payee = d['payee']
        if 'payee_ext' in d:
            o.payee_ext = d['payee_ext']
        if 'payer' in d:
            o.payer = d['payer']
        if 'payer_ext' in d:
            o.payer_ext = d['payer_ext']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ProductVOOptions(object):

    def __init__(self):
        self._include_condition_group = None
        self._include_prod_base = None
        self._include_prod_ip = None
        self._include_prod_lo = None
        self._include_prod_mark = None
        self._include_prod_rel = None
        self._include_prod_ri = None

    @property
    def include_condition_group(self):
        return self._include_condition_group

    @include_condition_group.setter
    def include_condition_group(self, value):
        self._include_condition_group = value
    @property
    def include_prod_base(self):
        return self._include_prod_base

    @include_prod_base.setter
    def include_prod_base(self, value):
        self._include_prod_base = value
    @property
    def include_prod_ip(self):
        return self._include_prod_ip

    @include_prod_ip.setter
    def include_prod_ip(self, value):
        self._include_prod_ip = value
    @property
    def include_prod_lo(self):
        return self._include_prod_lo

    @include_prod_lo.setter
    def include_prod_lo(self, value):
        self._include_prod_lo = value
    @property
    def include_prod_mark(self):
        return self._include_prod_mark

    @include_prod_mark.setter
    def include_prod_mark(self, value):
        self._include_prod_mark = value
    @property
    def include_prod_rel(self):
        return self._include_prod_rel

    @include_prod_rel.setter
    def include_prod_rel(self, value):
        self._include_prod_rel = value
    @property
    def include_prod_ri(self):
        return self._include_prod_ri

    @include_prod_ri.setter
    def include_prod_ri(self, value):
        self._include_prod_ri = value


    def to_alipay_dict(self):
        params = dict()
        if self.include_condition_group:
            if hasattr(self.include_condition_group, 'to_alipay_dict'):
                params['include_condition_group'] = self.include_condition_group.to_alipay_dict()
            else:
                params['include_condition_group'] = self.include_condition_group
        if self.include_prod_base:
            if hasattr(self.include_prod_base, 'to_alipay_dict'):
                params['include_prod_base'] = self.include_prod_base.to_alipay_dict()
            else:
                params['include_prod_base'] = self.include_prod_base
        if self.include_prod_ip:
            if hasattr(self.include_prod_ip, 'to_alipay_dict'):
                params['include_prod_ip'] = self.include_prod_ip.to_alipay_dict()
            else:
                params['include_prod_ip'] = self.include_prod_ip
        if self.include_prod_lo:
            if hasattr(self.include_prod_lo, 'to_alipay_dict'):
                params['include_prod_lo'] = self.include_prod_lo.to_alipay_dict()
            else:
                params['include_prod_lo'] = self.include_prod_lo
        if self.include_prod_mark:
            if hasattr(self.include_prod_mark, 'to_alipay_dict'):
                params['include_prod_mark'] = self.include_prod_mark.to_alipay_dict()
            else:
                params['include_prod_mark'] = self.include_prod_mark
        if self.include_prod_rel:
            if hasattr(self.include_prod_rel, 'to_alipay_dict'):
                params['include_prod_rel'] = self.include_prod_rel.to_alipay_dict()
            else:
                params['include_prod_rel'] = self.include_prod_rel
        if self.include_prod_ri:
            if hasattr(self.include_prod_ri, 'to_alipay_dict'):
                params['include_prod_ri'] = self.include_prod_ri.to_alipay_dict()
            else:
                params['include_prod_ri'] = self.include_prod_ri
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ProductVOOptions()
        if 'include_condition_group' in d:
            o.include_condition_group = d['include_condition_group']
        if 'include_prod_base' in d:
            o.include_prod_base = d['include_prod_base']
        if 'include_prod_ip' in d:
            o.include_prod_ip = d['include_prod_ip']
        if 'include_prod_lo' in d:
            o.include_prod_lo = d['include_prod_lo']
        if 'include_prod_mark' in d:
            o.include_prod_mark = d['include_prod_mark']
        if 'include_prod_rel' in d:
            o.include_prod_rel = d['include_prod_rel']
        if 'include_prod_ri' in d:
            o.include_prod_ri = d['include_prod_ri']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenActivity(object):

    def __init__(self):
        self._activity_end_date = None
        self._activity_id = None
        self._activity_name = None
        self._activity_start_date = None
        self._activity_status = None
        self._store_id = None

    @property
    def activity_end_date(self):
        return self._activity_end_date

    @activity_end_date.setter
    def activity_end_date(self, value):
        self._activity_end_date = value
    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def activity_name(self):
        return self._activity_name

    @activity_name.setter
    def activity_name(self, value):
        self._activity_name = value
    @property
    def activity_start_date(self):
        return self._activity_start_date

    @activity_start_date.setter
    def activity_start_date(self, value):
        self._activity_start_date = value
    @property
    def activity_status(self):
        return self._activity_status

    @activity_status.setter
    def activity_status(self, value):
        self._activity_status = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_end_date:
            if hasattr(self.activity_end_date, 'to_alipay_dict'):
                params['activity_end_date'] = self.activity_end_date.to_alipay_dict()
            else:
                params['activity_end_date'] = self.activity_end_date
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.activity_name:
            if hasattr(self.activity_name, 'to_alipay_dict'):
                params['activity_name'] = self.activity_name.to_alipay_dict()
            else:
                params['activity_name'] = self.activity_name
        if self.activity_start_date:
            if hasattr(self.activity_start_date, 'to_alipay_dict'):
                params['activity_start_date'] = self.activity_start_date.to_alipay_dict()
            else:
                params['activity_start_date'] = self.activity_start_date
        if self.activity_status:
            if hasattr(self.activity_status, 'to_alipay_dict'):
                params['activity_status'] = self.activity_status.to_alipay_dict()
            else:
                params['activity_status'] = self.activity_status
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenActivity()
        if 'activity_end_date' in d:
            o.activity_end_date = d['activity_end_date']
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'activity_name' in d:
            o.activity_name = d['activity_name']
        if 'activity_start_date' in d:
            o.activity_start_date = d['activity_start_date']
        if 'activity_status' in d:
            o.activity_status = d['activity_status']
        if 'store_id' in d:
            o.store_id = d['store_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantShopcodeApplyorderBatchqueryModel(object):

    def __init__(self):
        self._apply_ids = None
        self._end_time = None
        self._merchant_login_ids = None
        self._operator_id = None
        self._page_no = None
        self._page_size = None
        self._request_ids = None
        self._smids = None
        self._start_time = None

    @property
    def apply_ids(self):
        return self._apply_ids

    @apply_ids.setter
    def apply_ids(self, value):
        if isinstance(value, list):
            self._apply_ids = list()
            for i in value:
                self._apply_ids.append(i)
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def merchant_login_ids(self):
        return self._merchant_login_ids

    @merchant_login_ids.setter
    def merchant_login_ids(self, value):
        if isinstance(value, list):
            self._merchant_login_ids = list()
            for i in value:
                self._merchant_login_ids.append(i)
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def request_ids(self):
        return self._request_ids

    @request_ids.setter
    def request_ids(self, value):
        if isinstance(value, list):
            self._request_ids = list()
            for i in value:
                self._request_ids.append(i)
    @property
    def smids(self):
        return self._smids

    @smids.setter
    def smids(self, value):
        if isinstance(value, list):
            self._smids = list()
            for i in value:
                self._smids.append(i)
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_ids:
            if isinstance(self.apply_ids, list):
                for i in range(0, len(self.apply_ids)):
                    element = self.apply_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.apply_ids[i] = element.to_alipay_dict()
            if hasattr(self.apply_ids, 'to_alipay_dict'):
                params['apply_ids'] = self.apply_ids.to_alipay_dict()
            else:
                params['apply_ids'] = self.apply_ids
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.merchant_login_ids:
            if isinstance(self.merchant_login_ids, list):
                for i in range(0, len(self.merchant_login_ids)):
                    element = self.merchant_login_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.merchant_login_ids[i] = element.to_alipay_dict()
            if hasattr(self.merchant_login_ids, 'to_alipay_dict'):
                params['merchant_login_ids'] = self.merchant_login_ids.to_alipay_dict()
            else:
                params['merchant_login_ids'] = self.merchant_login_ids
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.request_ids:
            if isinstance(self.request_ids, list):
                for i in range(0, len(self.request_ids)):
                    element = self.request_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.request_ids[i] = element.to_alipay_dict()
            if hasattr(self.request_ids, 'to_alipay_dict'):
                params['request_ids'] = self.request_ids.to_alipay_dict()
            else:
                params['request_ids'] = self.request_ids
        if self.smids:
            if isinstance(self.smids, list):
                for i in range(0, len(self.smids)):
                    element = self.smids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.smids[i] = element.to_alipay_dict()
            if hasattr(self.smids, 'to_alipay_dict'):
                params['smids'] = self.smids.to_alipay_dict()
            else:
                params['smids'] = self.smids
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantShopcodeApplyorderBatchqueryModel()
        if 'apply_ids' in d:
            o.apply_ids = d['apply_ids']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'merchant_login_ids' in d:
            o.merchant_login_ids = d['merchant_login_ids']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'request_ids' in d:
            o.request_ids = d['request_ids']
        if 'smids' in d:
            o.smids = d['smids']
        if 'start_time' in d:
            o.start_time = d['start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTransferPaymentPrecreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTransferPaymentPrecreateResponse, self).__init__()
        self._pass_through_info = None
        self._transfer_id = None

    @property
    def pass_through_info(self):
        return self._pass_through_info

    @pass_through_info.setter
    def pass_through_info(self, value):
        self._pass_through_info = value
    @property
    def transfer_id(self):
        return self._transfer_id

    @transfer_id.setter
    def transfer_id(self, value):
        self._transfer_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTransferPaymentPrecreateResponse, self).parse_response_content(response_content)
        if 'pass_through_info' in response:
            self.pass_through_info = response['pass_through_info']
        if 'transfer_id' in response:
            self.transfer_id = response['transfer_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeZmgoAgreementUnsignResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeZmgoAgreementUnsignResponse, self).__init__()
        self._agreement_id = None
        self._withhold_plan_no = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def withhold_plan_no(self):
        return self._withhold_plan_no

    @withhold_plan_no.setter
    def withhold_plan_no(self, value):
        self._withhold_plan_no = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeZmgoAgreementUnsignResponse, self).parse_response_content(response_content)
        if 'agreement_id' in response:
            self.agreement_id = response['agreement_id']
        if 'withhold_plan_no' in response:
            self.withhold_plan_no = response['withhold_plan_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringEleOrderSyncModel(object):

    def __init__(self):
        self._action = None
        self._alipay_user_id = None
        self._data = None
        self._source = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringEleOrderSyncModel()
        if 'action' in d:
            o.action = d['action']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'data' in d:
            o.data = d['data']
        if 'source' in d:
            o.source = d['source']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMsaasMediarecogAftscvpayTransactionInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMsaasMediarecogAftscvpayTransactionInitializeResponse, self).__init__()
        self._result = None
        self._transaction_id = None

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def transaction_id(self):
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, value):
        self._transaction_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMsaasMediarecogAftscvpayTransactionInitializeResponse, self).parse_response_content(response_content)
        if 'result' in response:
            self.result = response['result']
        if 'transaction_id' in response:
            self.transaction_id = response['transaction_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ApplySubAccountAndBindOrder(object):

    def __init__(self):
        self._inst_id = None
        self._ip_role_id = None
        self._out_biz_no = None
        self._source = None
        self._treasury_business_type = None

    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def treasury_business_type(self):
        return self._treasury_business_type

    @treasury_business_type.setter
    def treasury_business_type(self, value):
        self._treasury_business_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.treasury_business_type:
            if hasattr(self.treasury_business_type, 'to_alipay_dict'):
                params['treasury_business_type'] = self.treasury_business_type.to_alipay_dict()
            else:
                params['treasury_business_type'] = self.treasury_business_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApplySubAccountAndBindOrder()
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'source' in d:
            o.source = d['source']
        if 'treasury_business_type' in d:
            o.treasury_business_type = d['treasury_business_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppFlowQualificationDetectResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppFlowQualificationDetectResponse, self).__init__()
        self._biz_code = None
        self._biz_desc = None
        self._mobile = None
        self._result_code = None
        self._result_msg = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_desc(self):
        return self._biz_desc

    @biz_desc.setter
    def biz_desc(self, value):
        self._biz_desc = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppFlowQualificationDetectResponse, self).parse_response_content(response_content)
        if 'biz_code' in response:
            self.biz_code = response['biz_code']
        if 'biz_desc' in response:
            self.biz_desc = response['biz_desc']
        if 'mobile' in response:
            self.mobile = response['mobile']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiItemExtitemUpdateModel(object):

    def __init__(self):
        self._brand_code = None
        self._category_code = None
        self._count = None
        self._country = None
        self._description = None
        self._id = None
        self._item_code = None
        self._picture = None
        self._price = None
        self._specification = None
        self._title = None

    @property
    def brand_code(self):
        return self._brand_code

    @brand_code.setter
    def brand_code(self, value):
        self._brand_code = value
    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def country(self):
        return self._country

    @country.setter
    def country(self, value):
        self._country = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def picture(self):
        return self._picture

    @picture.setter
    def picture(self, value):
        self._picture = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def specification(self):
        return self._specification

    @specification.setter
    def specification(self, value):
        self._specification = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_code:
            if hasattr(self.brand_code, 'to_alipay_dict'):
                params['brand_code'] = self.brand_code.to_alipay_dict()
            else:
                params['brand_code'] = self.brand_code
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.country:
            if hasattr(self.country, 'to_alipay_dict'):
                params['country'] = self.country.to_alipay_dict()
            else:
                params['country'] = self.country
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.picture:
            if hasattr(self.picture, 'to_alipay_dict'):
                params['picture'] = self.picture.to_alipay_dict()
            else:
                params['picture'] = self.picture
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.specification:
            if hasattr(self.specification, 'to_alipay_dict'):
                params['specification'] = self.specification.to_alipay_dict()
            else:
                params['specification'] = self.specification
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiItemExtitemUpdateModel()
        if 'brand_code' in d:
            o.brand_code = d['brand_code']
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'count' in d:
            o.count = d['count']
        if 'country' in d:
            o.country = d['country']
        if 'description' in d:
            o.description = d['description']
        if 'id' in d:
            o.id = d['id']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'picture' in d:
            o.picture = d['picture']
        if 'price' in d:
            o.price = d['price']
        if 'specification' in d:
            o.specification = d['specification']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeliveryActivityContentInfo import DeliveryActivityContentInfo


class DeliveryContentInfo(object):

    def __init__(self):
        self._delivery_activity_content = None
        self._delivery_content_type = None

    @property
    def delivery_activity_content(self):
        return self._delivery_activity_content

    @delivery_activity_content.setter
    def delivery_activity_content(self, value):
        if isinstance(value, DeliveryActivityContentInfo):
            self._delivery_activity_content = value
        else:
            self._delivery_activity_content = DeliveryActivityContentInfo.from_alipay_dict(value)
    @property
    def delivery_content_type(self):
        return self._delivery_content_type

    @delivery_content_type.setter
    def delivery_content_type(self, value):
        self._delivery_content_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_activity_content:
            if hasattr(self.delivery_activity_content, 'to_alipay_dict'):
                params['delivery_activity_content'] = self.delivery_activity_content.to_alipay_dict()
            else:
                params['delivery_activity_content'] = self.delivery_activity_content
        if self.delivery_content_type:
            if hasattr(self.delivery_content_type, 'to_alipay_dict'):
                params['delivery_content_type'] = self.delivery_content_type.to_alipay_dict()
            else:
                params['delivery_content_type'] = self.delivery_content_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeliveryContentInfo()
        if 'delivery_activity_content' in d:
            o.delivery_activity_content = d['delivery_activity_content']
        if 'delivery_content_type' in d:
            o.delivery_content_type = d['delivery_content_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingCampaignActivityOfflineTriggerResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignActivityOfflineTriggerResponse, self).__init__()
        self._out_prize_id = None

    @property
    def out_prize_id(self):
        return self._out_prize_id

    @out_prize_id.setter
    def out_prize_id(self, value):
        self._out_prize_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignActivityOfflineTriggerResponse, self).parse_response_content(response_content)
        if 'out_prize_id' in response:
            self.out_prize_id = response['out_prize_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAliyunbenefitReceiveModel(object):

    def __init__(self):
        self._biz_date = None
        self._ext_json = None
        self._item_id = None
        self._out_biz_no = None
        self._price_strategy = None
        self._user_id = None
        self._verify_point = None

    @property
    def biz_date(self):
        return self._biz_date

    @biz_date.setter
    def biz_date(self, value):
        self._biz_date = value
    @property
    def ext_json(self):
        return self._ext_json

    @ext_json.setter
    def ext_json(self, value):
        self._ext_json = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def price_strategy(self):
        return self._price_strategy

    @price_strategy.setter
    def price_strategy(self, value):
        self._price_strategy = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def verify_point(self):
        return self._verify_point

    @verify_point.setter
    def verify_point(self, value):
        self._verify_point = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_date:
            if hasattr(self.biz_date, 'to_alipay_dict'):
                params['biz_date'] = self.biz_date.to_alipay_dict()
            else:
                params['biz_date'] = self.biz_date
        if self.ext_json:
            if hasattr(self.ext_json, 'to_alipay_dict'):
                params['ext_json'] = self.ext_json.to_alipay_dict()
            else:
                params['ext_json'] = self.ext_json
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.price_strategy:
            if hasattr(self.price_strategy, 'to_alipay_dict'):
                params['price_strategy'] = self.price_strategy.to_alipay_dict()
            else:
                params['price_strategy'] = self.price_strategy
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.verify_point:
            if hasattr(self.verify_point, 'to_alipay_dict'):
                params['verify_point'] = self.verify_point.to_alipay_dict()
            else:
                params['verify_point'] = self.verify_point
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAliyunbenefitReceiveModel()
        if 'biz_date' in d:
            o.biz_date = d['biz_date']
        if 'ext_json' in d:
            o.ext_json = d['ext_json']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'price_strategy' in d:
            o.price_strategy = d['price_strategy']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'verify_point' in d:
            o.verify_point = d['verify_point']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EsignResult(object):

    def __init__(self):
        self._agreement_url = None
        self._apply_dutiable_mode_enum = None
        self._contractor_code = None
        self._contractor_name = None
        self._employer_code = None
        self._identification_in_belonging_employer = None
        self._pay_salary_mode_enum = None
        self._sign_time = None
        self._status = None
        self._tax_optimization_mode = None
        self._termination_time = None

    @property
    def agreement_url(self):
        return self._agreement_url

    @agreement_url.setter
    def agreement_url(self, value):
        self._agreement_url = value
    @property
    def apply_dutiable_mode_enum(self):
        return self._apply_dutiable_mode_enum

    @apply_dutiable_mode_enum.setter
    def apply_dutiable_mode_enum(self, value):
        self._apply_dutiable_mode_enum = value
    @property
    def contractor_code(self):
        return self._contractor_code

    @contractor_code.setter
    def contractor_code(self, value):
        self._contractor_code = value
    @property
    def contractor_name(self):
        return self._contractor_name

    @contractor_name.setter
    def contractor_name(self, value):
        self._contractor_name = value
    @property
    def employer_code(self):
        return self._employer_code

    @employer_code.setter
    def employer_code(self, value):
        self._employer_code = value
    @property
    def identification_in_belonging_employer(self):
        return self._identification_in_belonging_employer

    @identification_in_belonging_employer.setter
    def identification_in_belonging_employer(self, value):
        self._identification_in_belonging_employer = value
    @property
    def pay_salary_mode_enum(self):
        return self._pay_salary_mode_enum

    @pay_salary_mode_enum.setter
    def pay_salary_mode_enum(self, value):
        self._pay_salary_mode_enum = value
    @property
    def sign_time(self):
        return self._sign_time

    @sign_time.setter
    def sign_time(self, value):
        self._sign_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tax_optimization_mode(self):
        return self._tax_optimization_mode

    @tax_optimization_mode.setter
    def tax_optimization_mode(self, value):
        self._tax_optimization_mode = value
    @property
    def termination_time(self):
        return self._termination_time

    @termination_time.setter
    def termination_time(self, value):
        self._termination_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_url:
            if hasattr(self.agreement_url, 'to_alipay_dict'):
                params['agreement_url'] = self.agreement_url.to_alipay_dict()
            else:
                params['agreement_url'] = self.agreement_url
        if self.apply_dutiable_mode_enum:
            if hasattr(self.apply_dutiable_mode_enum, 'to_alipay_dict'):
                params['apply_dutiable_mode_enum'] = self.apply_dutiable_mode_enum.to_alipay_dict()
            else:
                params['apply_dutiable_mode_enum'] = self.apply_dutiable_mode_enum
        if self.contractor_code:
            if hasattr(self.contractor_code, 'to_alipay_dict'):
                params['contractor_code'] = self.contractor_code.to_alipay_dict()
            else:
                params['contractor_code'] = self.contractor_code
        if self.contractor_name:
            if hasattr(self.contractor_name, 'to_alipay_dict'):
                params['contractor_name'] = self.contractor_name.to_alipay_dict()
            else:
                params['contractor_name'] = self.contractor_name
        if self.employer_code:
            if hasattr(self.employer_code, 'to_alipay_dict'):
                params['employer_code'] = self.employer_code.to_alipay_dict()
            else:
                params['employer_code'] = self.employer_code
        if self.identification_in_belonging_employer:
            if hasattr(self.identification_in_belonging_employer, 'to_alipay_dict'):
                params['identification_in_belonging_employer'] = self.identification_in_belonging_employer.to_alipay_dict()
            else:
                params['identification_in_belonging_employer'] = self.identification_in_belonging_employer
        if self.pay_salary_mode_enum:
            if hasattr(self.pay_salary_mode_enum, 'to_alipay_dict'):
                params['pay_salary_mode_enum'] = self.pay_salary_mode_enum.to_alipay_dict()
            else:
                params['pay_salary_mode_enum'] = self.pay_salary_mode_enum
        if self.sign_time:
            if hasattr(self.sign_time, 'to_alipay_dict'):
                params['sign_time'] = self.sign_time.to_alipay_dict()
            else:
                params['sign_time'] = self.sign_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tax_optimization_mode:
            if hasattr(self.tax_optimization_mode, 'to_alipay_dict'):
                params['tax_optimization_mode'] = self.tax_optimization_mode.to_alipay_dict()
            else:
                params['tax_optimization_mode'] = self.tax_optimization_mode
        if self.termination_time:
            if hasattr(self.termination_time, 'to_alipay_dict'):
                params['termination_time'] = self.termination_time.to_alipay_dict()
            else:
                params['termination_time'] = self.termination_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EsignResult()
        if 'agreement_url' in d:
            o.agreement_url = d['agreement_url']
        if 'apply_dutiable_mode_enum' in d:
            o.apply_dutiable_mode_enum = d['apply_dutiable_mode_enum']
        if 'contractor_code' in d:
            o.contractor_code = d['contractor_code']
        if 'contractor_name' in d:
            o.contractor_name = d['contractor_name']
        if 'employer_code' in d:
            o.employer_code = d['employer_code']
        if 'identification_in_belonging_employer' in d:
            o.identification_in_belonging_employer = d['identification_in_belonging_employer']
        if 'pay_salary_mode_enum' in d:
            o.pay_salary_mode_enum = d['pay_salary_mode_enum']
        if 'sign_time' in d:
            o.sign_time = d['sign_time']
        if 'status' in d:
            o.status = d['status']
        if 'tax_optimization_mode' in d:
            o.tax_optimization_mode = d['tax_optimization_mode']
        if 'termination_time' in d:
            o.termination_time = d['termination_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosDiscountDetail import PosDiscountDetail
from alipay.aop.api.domain.KbPosBillDishDetail import KbPosBillDishDetail
from alipay.aop.api.domain.PosBillPayChannel import PosBillPayChannel
from alipay.aop.api.domain.PosOrderKey import PosOrderKey


class KoubeiCateringOrderBillApplyModel(object):

    def __init__(self):
        self._bill_amount = None
        self._discount_details = None
        self._dish_details = None
        self._ext_info = None
        self._member_flag = None
        self._memo = None
        self._pay_amount = None
        self._pay_channels = None
        self._people_list = None
        self._pos_order_key = None
        self._receipt_amount = None
        self._settle_time = None

    @property
    def bill_amount(self):
        return self._bill_amount

    @bill_amount.setter
    def bill_amount(self, value):
        self._bill_amount = value
    @property
    def discount_details(self):
        return self._discount_details

    @discount_details.setter
    def discount_details(self, value):
        if isinstance(value, list):
            self._discount_details = list()
            for i in value:
                if isinstance(i, PosDiscountDetail):
                    self._discount_details.append(i)
                else:
                    self._discount_details.append(PosDiscountDetail.from_alipay_dict(i))
    @property
    def dish_details(self):
        return self._dish_details

    @dish_details.setter
    def dish_details(self, value):
        if isinstance(value, list):
            self._dish_details = list()
            for i in value:
                if isinstance(i, KbPosBillDishDetail):
                    self._dish_details.append(i)
                else:
                    self._dish_details.append(KbPosBillDishDetail.from_alipay_dict(i))
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def member_flag(self):
        return self._member_flag

    @member_flag.setter
    def member_flag(self, value):
        self._member_flag = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pay_channels(self):
        return self._pay_channels

    @pay_channels.setter
    def pay_channels(self, value):
        if isinstance(value, list):
            self._pay_channels = list()
            for i in value:
                if isinstance(i, PosBillPayChannel):
                    self._pay_channels.append(i)
                else:
                    self._pay_channels.append(PosBillPayChannel.from_alipay_dict(i))
    @property
    def people_list(self):
        return self._people_list

    @people_list.setter
    def people_list(self, value):
        self._people_list = value
    @property
    def pos_order_key(self):
        return self._pos_order_key

    @pos_order_key.setter
    def pos_order_key(self, value):
        if isinstance(value, PosOrderKey):
            self._pos_order_key = value
        else:
            self._pos_order_key = PosOrderKey.from_alipay_dict(value)
    @property
    def receipt_amount(self):
        return self._receipt_amount

    @receipt_amount.setter
    def receipt_amount(self, value):
        self._receipt_amount = value
    @property
    def settle_time(self):
        return self._settle_time

    @settle_time.setter
    def settle_time(self, value):
        self._settle_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_amount:
            if hasattr(self.bill_amount, 'to_alipay_dict'):
                params['bill_amount'] = self.bill_amount.to_alipay_dict()
            else:
                params['bill_amount'] = self.bill_amount
        if self.discount_details:
            if isinstance(self.discount_details, list):
                for i in range(0, len(self.discount_details)):
                    element = self.discount_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.discount_details[i] = element.to_alipay_dict()
            if hasattr(self.discount_details, 'to_alipay_dict'):
                params['discount_details'] = self.discount_details.to_alipay_dict()
            else:
                params['discount_details'] = self.discount_details
        if self.dish_details:
            if isinstance(self.dish_details, list):
                for i in range(0, len(self.dish_details)):
                    element = self.dish_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_details[i] = element.to_alipay_dict()
            if hasattr(self.dish_details, 'to_alipay_dict'):
                params['dish_details'] = self.dish_details.to_alipay_dict()
            else:
                params['dish_details'] = self.dish_details
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.member_flag:
            if hasattr(self.member_flag, 'to_alipay_dict'):
                params['member_flag'] = self.member_flag.to_alipay_dict()
            else:
                params['member_flag'] = self.member_flag
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.pay_channels:
            if isinstance(self.pay_channels, list):
                for i in range(0, len(self.pay_channels)):
                    element = self.pay_channels[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pay_channels[i] = element.to_alipay_dict()
            if hasattr(self.pay_channels, 'to_alipay_dict'):
                params['pay_channels'] = self.pay_channels.to_alipay_dict()
            else:
                params['pay_channels'] = self.pay_channels
        if self.people_list:
            if hasattr(self.people_list, 'to_alipay_dict'):
                params['people_list'] = self.people_list.to_alipay_dict()
            else:
                params['people_list'] = self.people_list
        if self.pos_order_key:
            if hasattr(self.pos_order_key, 'to_alipay_dict'):
                params['pos_order_key'] = self.pos_order_key.to_alipay_dict()
            else:
                params['pos_order_key'] = self.pos_order_key
        if self.receipt_amount:
            if hasattr(self.receipt_amount, 'to_alipay_dict'):
                params['receipt_amount'] = self.receipt_amount.to_alipay_dict()
            else:
                params['receipt_amount'] = self.receipt_amount
        if self.settle_time:
            if hasattr(self.settle_time, 'to_alipay_dict'):
                params['settle_time'] = self.settle_time.to_alipay_dict()
            else:
                params['settle_time'] = self.settle_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringOrderBillApplyModel()
        if 'bill_amount' in d:
            o.bill_amount = d['bill_amount']
        if 'discount_details' in d:
            o.discount_details = d['discount_details']
        if 'dish_details' in d:
            o.dish_details = d['dish_details']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'member_flag' in d:
            o.member_flag = d['member_flag']
        if 'memo' in d:
            o.memo = d['memo']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'pay_channels' in d:
            o.pay_channels = d['pay_channels']
        if 'people_list' in d:
            o.people_list = d['people_list']
        if 'pos_order_key' in d:
            o.pos_order_key = d['pos_order_key']
        if 'receipt_amount' in d:
            o.receipt_amount = d['receipt_amount']
        if 'settle_time' in d:
            o.settle_time = d['settle_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IcrowdUseParam import IcrowdUseParam


class AlipayDataDataserviceIcrowdUseModel(object):

    def __init__(self):
        self._icrowd_use_param = None

    @property
    def icrowd_use_param(self):
        return self._icrowd_use_param

    @icrowd_use_param.setter
    def icrowd_use_param(self, value):
        if isinstance(value, IcrowdUseParam):
            self._icrowd_use_param = value
        else:
            self._icrowd_use_param = IcrowdUseParam.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.icrowd_use_param:
            if hasattr(self.icrowd_use_param, 'to_alipay_dict'):
                params['icrowd_use_param'] = self.icrowd_use_param.to_alipay_dict()
            else:
                params['icrowd_use_param'] = self.icrowd_use_param
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceIcrowdUseModel()
        if 'icrowd_use_param' in d:
            o.icrowd_use_param = d['icrowd_use_param']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CardPriceRequestItem(object):

    def __init__(self):
        self._base_price_cent = None
        self._card_type = None
        self._default_promo_price_cent = None
        self._high_price_cent = None
        self._last_promo_price = None
        self._lower_price_cent = None
        self._pricing = None
        self._visible = None

    @property
    def base_price_cent(self):
        return self._base_price_cent

    @base_price_cent.setter
    def base_price_cent(self, value):
        self._base_price_cent = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def default_promo_price_cent(self):
        return self._default_promo_price_cent

    @default_promo_price_cent.setter
    def default_promo_price_cent(self, value):
        self._default_promo_price_cent = value
    @property
    def high_price_cent(self):
        return self._high_price_cent

    @high_price_cent.setter
    def high_price_cent(self, value):
        self._high_price_cent = value
    @property
    def last_promo_price(self):
        return self._last_promo_price

    @last_promo_price.setter
    def last_promo_price(self, value):
        self._last_promo_price = value
    @property
    def lower_price_cent(self):
        return self._lower_price_cent

    @lower_price_cent.setter
    def lower_price_cent(self, value):
        self._lower_price_cent = value
    @property
    def pricing(self):
        return self._pricing

    @pricing.setter
    def pricing(self, value):
        self._pricing = value
    @property
    def visible(self):
        return self._visible

    @visible.setter
    def visible(self, value):
        self._visible = value


    def to_alipay_dict(self):
        params = dict()
        if self.base_price_cent:
            if hasattr(self.base_price_cent, 'to_alipay_dict'):
                params['base_price_cent'] = self.base_price_cent.to_alipay_dict()
            else:
                params['base_price_cent'] = self.base_price_cent
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.default_promo_price_cent:
            if hasattr(self.default_promo_price_cent, 'to_alipay_dict'):
                params['default_promo_price_cent'] = self.default_promo_price_cent.to_alipay_dict()
            else:
                params['default_promo_price_cent'] = self.default_promo_price_cent
        if self.high_price_cent:
            if hasattr(self.high_price_cent, 'to_alipay_dict'):
                params['high_price_cent'] = self.high_price_cent.to_alipay_dict()
            else:
                params['high_price_cent'] = self.high_price_cent
        if self.last_promo_price:
            if hasattr(self.last_promo_price, 'to_alipay_dict'):
                params['last_promo_price'] = self.last_promo_price.to_alipay_dict()
            else:
                params['last_promo_price'] = self.last_promo_price
        if self.lower_price_cent:
            if hasattr(self.lower_price_cent, 'to_alipay_dict'):
                params['lower_price_cent'] = self.lower_price_cent.to_alipay_dict()
            else:
                params['lower_price_cent'] = self.lower_price_cent
        if self.pricing:
            if hasattr(self.pricing, 'to_alipay_dict'):
                params['pricing'] = self.pricing.to_alipay_dict()
            else:
                params['pricing'] = self.pricing
        if self.visible:
            if hasattr(self.visible, 'to_alipay_dict'):
                params['visible'] = self.visible.to_alipay_dict()
            else:
                params['visible'] = self.visible
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CardPriceRequestItem()
        if 'base_price_cent' in d:
            o.base_price_cent = d['base_price_cent']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'default_promo_price_cent' in d:
            o.default_promo_price_cent = d['default_promo_price_cent']
        if 'high_price_cent' in d:
            o.high_price_cent = d['high_price_cent']
        if 'last_promo_price' in d:
            o.last_promo_price = d['last_promo_price']
        if 'lower_price_cent' in d:
            o.lower_price_cent = d['lower_price_cent']
        if 'pricing' in d:
            o.pricing = d['pricing']
        if 'visible' in d:
            o.visible = d['visible']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAgreementMigrateModel(object):

    def __init__(self):
        self._agreement_no = None
        self._target_app_id = None
        self._target_invoke_app_id = None
        self._target_partner_id = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def target_app_id(self):
        return self._target_app_id

    @target_app_id.setter
    def target_app_id(self, value):
        self._target_app_id = value
    @property
    def target_invoke_app_id(self):
        return self._target_invoke_app_id

    @target_invoke_app_id.setter
    def target_invoke_app_id(self, value):
        self._target_invoke_app_id = value
    @property
    def target_partner_id(self):
        return self._target_partner_id

    @target_partner_id.setter
    def target_partner_id(self, value):
        self._target_partner_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.target_app_id:
            if hasattr(self.target_app_id, 'to_alipay_dict'):
                params['target_app_id'] = self.target_app_id.to_alipay_dict()
            else:
                params['target_app_id'] = self.target_app_id
        if self.target_invoke_app_id:
            if hasattr(self.target_invoke_app_id, 'to_alipay_dict'):
                params['target_invoke_app_id'] = self.target_invoke_app_id.to_alipay_dict()
            else:
                params['target_invoke_app_id'] = self.target_invoke_app_id
        if self.target_partner_id:
            if hasattr(self.target_partner_id, 'to_alipay_dict'):
                params['target_partner_id'] = self.target_partner_id.to_alipay_dict()
            else:
                params['target_partner_id'] = self.target_partner_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAgreementMigrateModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'target_app_id' in d:
            o.target_app_id = d['target_app_id']
        if 'target_invoke_app_id' in d:
            o.target_invoke_app_id = d['target_invoke_app_id']
        if 'target_partner_id' in d:
            o.target_partner_id = d['target_partner_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncPriceAutoCreateModel(object):

    def __init__(self):
        self._app_name = None
        self._biz_unit_code = None
        self._commodity_code = None
        self._commodity_name = None
        self._commodity_version = None
        self._creator_id = None
        self._creator_nm = None
        self._gmt_invalid = None
        self._gmt_valid = None
        self._inst_id = None
        self._memo = None
        self._out_biz_no = None
        self._price_name = None
        self._price_origin = None
        self._price_tpl_id = None
        self._price_tpl_version = None
        self._tnt_inst_id = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def biz_unit_code(self):
        return self._biz_unit_code

    @biz_unit_code.setter
    def biz_unit_code(self, value):
        self._biz_unit_code = value
    @property
    def commodity_code(self):
        return self._commodity_code

    @commodity_code.setter
    def commodity_code(self, value):
        self._commodity_code = value
    @property
    def commodity_name(self):
        return self._commodity_name

    @commodity_name.setter
    def commodity_name(self, value):
        self._commodity_name = value
    @property
    def commodity_version(self):
        return self._commodity_version

    @commodity_version.setter
    def commodity_version(self, value):
        self._commodity_version = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def creator_nm(self):
        return self._creator_nm

    @creator_nm.setter
    def creator_nm(self, value):
        self._creator_nm = value
    @property
    def gmt_invalid(self):
        return self._gmt_invalid

    @gmt_invalid.setter
    def gmt_invalid(self, value):
        self._gmt_invalid = value
    @property
    def gmt_valid(self):
        return self._gmt_valid

    @gmt_valid.setter
    def gmt_valid(self, value):
        self._gmt_valid = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def price_name(self):
        return self._price_name

    @price_name.setter
    def price_name(self, value):
        self._price_name = value
    @property
    def price_origin(self):
        return self._price_origin

    @price_origin.setter
    def price_origin(self, value):
        self._price_origin = value
    @property
    def price_tpl_id(self):
        return self._price_tpl_id

    @price_tpl_id.setter
    def price_tpl_id(self, value):
        self._price_tpl_id = value
    @property
    def price_tpl_version(self):
        return self._price_tpl_version

    @price_tpl_version.setter
    def price_tpl_version(self, value):
        self._price_tpl_version = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.biz_unit_code:
            if hasattr(self.biz_unit_code, 'to_alipay_dict'):
                params['biz_unit_code'] = self.biz_unit_code.to_alipay_dict()
            else:
                params['biz_unit_code'] = self.biz_unit_code
        if self.commodity_code:
            if hasattr(self.commodity_code, 'to_alipay_dict'):
                params['commodity_code'] = self.commodity_code.to_alipay_dict()
            else:
                params['commodity_code'] = self.commodity_code
        if self.commodity_name:
            if hasattr(self.commodity_name, 'to_alipay_dict'):
                params['commodity_name'] = self.commodity_name.to_alipay_dict()
            else:
                params['commodity_name'] = self.commodity_name
        if self.commodity_version:
            if hasattr(self.commodity_version, 'to_alipay_dict'):
                params['commodity_version'] = self.commodity_version.to_alipay_dict()
            else:
                params['commodity_version'] = self.commodity_version
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.creator_nm:
            if hasattr(self.creator_nm, 'to_alipay_dict'):
                params['creator_nm'] = self.creator_nm.to_alipay_dict()
            else:
                params['creator_nm'] = self.creator_nm
        if self.gmt_invalid:
            if hasattr(self.gmt_invalid, 'to_alipay_dict'):
                params['gmt_invalid'] = self.gmt_invalid.to_alipay_dict()
            else:
                params['gmt_invalid'] = self.gmt_invalid
        if self.gmt_valid:
            if hasattr(self.gmt_valid, 'to_alipay_dict'):
                params['gmt_valid'] = self.gmt_valid.to_alipay_dict()
            else:
                params['gmt_valid'] = self.gmt_valid
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.price_name:
            if hasattr(self.price_name, 'to_alipay_dict'):
                params['price_name'] = self.price_name.to_alipay_dict()
            else:
                params['price_name'] = self.price_name
        if self.price_origin:
            if hasattr(self.price_origin, 'to_alipay_dict'):
                params['price_origin'] = self.price_origin.to_alipay_dict()
            else:
                params['price_origin'] = self.price_origin
        if self.price_tpl_id:
            if hasattr(self.price_tpl_id, 'to_alipay_dict'):
                params['price_tpl_id'] = self.price_tpl_id.to_alipay_dict()
            else:
                params['price_tpl_id'] = self.price_tpl_id
        if self.price_tpl_version:
            if hasattr(self.price_tpl_version, 'to_alipay_dict'):
                params['price_tpl_version'] = self.price_tpl_version.to_alipay_dict()
            else:
                params['price_tpl_version'] = self.price_tpl_version
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncPriceAutoCreateModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'biz_unit_code' in d:
            o.biz_unit_code = d['biz_unit_code']
        if 'commodity_code' in d:
            o.commodity_code = d['commodity_code']
        if 'commodity_name' in d:
            o.commodity_name = d['commodity_name']
        if 'commodity_version' in d:
            o.commodity_version = d['commodity_version']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'creator_nm' in d:
            o.creator_nm = d['creator_nm']
        if 'gmt_invalid' in d:
            o.gmt_invalid = d['gmt_invalid']
        if 'gmt_valid' in d:
            o.gmt_valid = d['gmt_valid']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'price_name' in d:
            o.price_name = d['price_name']
        if 'price_origin' in d:
            o.price_origin = d['price_origin']
        if 'price_tpl_id' in d:
            o.price_tpl_id = d['price_tpl_id']
        if 'price_tpl_version' in d:
            o.price_tpl_version = d['price_tpl_version']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiTradeOrderAggregateRefundResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiTradeOrderAggregateRefundResponse, self).__init__()
        self._gmt_refund_time = None
        self._order_no = None
        self._order_status = None
        self._out_order_no = None
        self._out_refund_no = None
        self._refund_amount = None
        self._refund_buyer_amount = None
        self._refund_discount_amount = None
        self._refund_mdiscount_amount = None
        self._refund_order_id = None
        self._refund_real_amount = None
        self._trade_no = None

    @property
    def gmt_refund_time(self):
        return self._gmt_refund_time

    @gmt_refund_time.setter
    def gmt_refund_time(self, value):
        self._gmt_refund_time = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_refund_no(self):
        return self._out_refund_no

    @out_refund_no.setter
    def out_refund_no(self, value):
        self._out_refund_no = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_buyer_amount(self):
        return self._refund_buyer_amount

    @refund_buyer_amount.setter
    def refund_buyer_amount(self, value):
        self._refund_buyer_amount = value
    @property
    def refund_discount_amount(self):
        return self._refund_discount_amount

    @refund_discount_amount.setter
    def refund_discount_amount(self, value):
        self._refund_discount_amount = value
    @property
    def refund_mdiscount_amount(self):
        return self._refund_mdiscount_amount

    @refund_mdiscount_amount.setter
    def refund_mdiscount_amount(self, value):
        self._refund_mdiscount_amount = value
    @property
    def refund_order_id(self):
        return self._refund_order_id

    @refund_order_id.setter
    def refund_order_id(self, value):
        self._refund_order_id = value
    @property
    def refund_real_amount(self):
        return self._refund_real_amount

    @refund_real_amount.setter
    def refund_real_amount(self, value):
        self._refund_real_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(KoubeiTradeOrderAggregateRefundResponse, self).parse_response_content(response_content)
        if 'gmt_refund_time' in response:
            self.gmt_refund_time = response['gmt_refund_time']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'out_refund_no' in response:
            self.out_refund_no = response['out_refund_no']
        if 'refund_amount' in response:
            self.refund_amount = response['refund_amount']
        if 'refund_buyer_amount' in response:
            self.refund_buyer_amount = response['refund_buyer_amount']
        if 'refund_discount_amount' in response:
            self.refund_discount_amount = response['refund_discount_amount']
        if 'refund_mdiscount_amount' in response:
            self.refund_mdiscount_amount = response['refund_mdiscount_amount']
        if 'refund_order_id' in response:
            self.refund_order_id = response['refund_order_id']
        if 'refund_real_amount' in response:
            self.refund_real_amount = response['refund_real_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
